Registerable

Trait Registerable 

pub trait Registerable: 'static { }
A marker trait for all types that can be registered with Registry::transient.

It’s automatically implemented for all types that are valid. Generally, those are all types with a 'static lifetime.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> Registerable for T
where T: 'static,